@@ -2,6 +2,7 @@ package AnyEvent::Open3::Simple;
 
 use strict;
 use warnings;
+use 5.006;
 use warnings::register;
 use AnyEvent;
 use IPC::Open3 qw( open3 );
@@ -12,7 +13,7 @@ use Carp qw( croak );
 use File::Temp ();
 
 # ABSTRACT: Interface to open3 under AnyEvent
-our $VERSION = '0.81'; # VERSION
+our $VERSION = '0.82'; # VERSION
 
 
 sub new
@@ -226,7 +227,7 @@ AnyEvent::Open3::Simple - Interface to open3 under AnyEvent
 
 =head1 VERSION
 
-version 0.81
+version 0.82
 
 =head1 SYNOPSIS
 
@@ -518,9 +519,9 @@ L<AnyEvent::Subprocess>, L<AnyEvent::Util>, L<AnyEvent::Run>.
 
 =head1 AUTHOR
 
-author: Graham Ollis <plicease@cpan.org>
+Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Stephen R. Scaffidi
 
