@@ -2,9 +2,10 @@ package AnyEvent::Open3::Simple::Process;
 
 use strict;
 use warnings;
+use 5.006;
 
 # ABSTRACT: Process run using AnyEvent::Open3::Simple
-our $VERSION = '0.81'; # VERSION
+our $VERSION = '0.82'; # VERSION
 
 
 sub new
@@ -63,7 +64,7 @@ AnyEvent::Open3::Simple::Process - Process run using AnyEvent::Open3::Simple
 
 =head1 VERSION
 
-version 0.81
+version 0.82
 
 =head1 DESCRIPTION
 
@@ -138,9 +139,9 @@ between callbacks, for example:
 
 =head1 AUTHOR
 
-author: Graham Ollis <plicease@cpan.org>
+Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Stephen R. Scaffidi
 
